@@ -73,7 +73,7 @@ class Message(object):
 		self._message = MIMEMultipart() # ('related')
 		self._processed = False
 		self._attachments = []
-		self._charset = [turbogears.config.get("mail.encoding", 'us-ascii'), encoding][encoding is None]
+		self._charset = [encoding, turbogears.config.get("mail.encoding", 'us-ascii')][encoding is None]
 		
 		self.plain = None
 		self.rich = None
